## ###########################################################################
## cleanup - clean directories of unneeded IRACproc output
##
## (c) 2008 SAO, Mike Schuster - mschuster@cfa.harvard.edu
##
## ############################################################################

=head1 NAME

 perl cleanup.pl - clean directories of unneeded IRACproc output


=head1 SYNOPSIS

 % perl cleanup.pl [--help][--ver][--dirlist file][dir1 dir2 ... dirN]


=head1 COMMAND LINE OPTIONS

 --help
   Print usage information and exit.

 --ver
   Print current version and exit.

 --dirlist
   File with list of directories to clean

 dir1 dir2 ... dirN
   Directory list to clean (either this list or the --dirlist 
   file option should be given)


=head1 DESCRIPTION



=head1 CHANGES

 1.0 - Initial version (Jul 30, 2008)


=head1 AUTHOR

 (c) 2008 Mike Schuster (mschuster@cfa.harvard.edu)
 (c) 2008 SAO - Smithsonian Astrophysical Observatory


=head1 SEE ALSO



=head1 BUGS

Report bugs to Mike Schuster, mschuster@cfa.harvard.edu


=cut

## ############################################################################
## Set Modules and version number
## ############################################################################

use warnings;
use strict;
use diagnostics;
use Getopt::Long;

# Set number version
my $VERSION = '1.0';           # Script version number
my $pname   = 'cleanup.pl';    # Script name


## ############################################################################
## Read input options
## ############################################################################

my ($help,$ver,$dirlist);

my %optctl = (help            => \$help,
              ver             => \$ver,
              dirlist         => \$dirlist,
             );

&GetOptions(\%optctl,
            "help",
            "ver",
            "dirlist=s",
           );


## ############################################################################
## Process input options
## ############################################################################

# Print help and exit
my $usg = "USAGE:  perl $pname [--help][--ver][--dirlist file][dir1 dir2 ... dirN]\n";

if ($help) {
  print STDOUT <<HELP;

  $pname version $VERSION

  Clean directories of IRACproc output

  $usg

HELP
  exit 0;
}

# Print version and exit
if ($ver) { 
  print "$pname: version $VERSION\n"; 
  exit 0;
}


## ############################################################################
## Read input parameters
## ############################################################################

my @dlist;

# Check the 'dirlist' option
if ($dirlist) {
  open(DIR,$dirlist) or die "$pname: cannot open file $dirlist\n";
  foreach (<DIR>) {
	if (m/^ *$/) { next; }
	if (m/^ *\#/) { next; }
	chomp;
	push @dlist,$_;
  }
  close(DIR);
}

# Check the 'dir' option
my $NARGV = scalar @ARGV;
if (not $dirlist) {
  if ($NARGV<1) { print $usg; exit 1; }
  @dlist = @ARGV;
} else { 
  if ($NARGV>1) {print "$pname: WARNING: using DIRs from --dirlist option\n"; } 
}

# Set number of dirs
my $ndirs = scalar @dlist;
if ($ndirs<1) {
  print "$pname: you should give either a list of DIRs or ";
  print "an DIR list file with the --dirlist option\n";
  print $usg; exit 1;
}


## ############################################################################
## Clean unneeded IRACproc output
## ############################################################################

my ($f,$i,$dir,$sub,$old);

foreach my $topdir (@dlist) {

  print "$pname: working on DIR $topdir\n";
  # Check if directory exists
  if (-f $topdir) {
    print "$pname: ERROR: cannot clean $topdir. ";
    print "There is a file with that name.\n";
    next;
  }

  for ($f=1; $f<+5;$f++) {

#    $old = $topdir."/PSFsub/";
#    if (-d $old) {
#      print "$old => $topdir/analysis/\n";
#      system "mv $old $topdir/analysis/";
#    }
#    $old = $topdir."/measure";
#    if (-d $old) {
#      print "cp $old/* => $topdir/analysis/\n";
#      system "cp $old/* $topdir/analysis/";
#      system "rm -rf $old";
#    }
    $old = $topdir."/useless/";
    if (-d $old) { system "rm -rf $old"; }
    $old = $topdir."/ch".$f."/";
    if (-d $old) { system "rm -rf $old"; }

    for ($i=1; $i<+5;$i++) {

    $dir = "";
    if ($i==1) { $dir = $topdir."/median_I".$f."/"; }
    if ($i==2) { $dir = $topdir."/minabs_I".$f."/"; }
    if ($i==3) { $dir = $topdir."/mosaic_I".$f."/";}
#    if ($i==4) { $dir = $topdir."/overlap_I".$f."/"; }

    if (-d $dir) {
      print "Cleaning up $dir output data ";
      $sub = $dir."Coadd/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      $sub = $dir."Interp/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      $sub = $dir."Outlier/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      $sub = $dir."ReInterp/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      $sub = $dir."Rmask/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      $sub = $dir."Rmask_Mosaic/";
      if (-d $sub) {
        system "rm -rf $sub";
        print ".";
      }
      print "\n";
    }

    }

  }

}


## ############################################################################
## End
## ############################################################################

exit 0;
