## ############################################################################
## multi_fixup - runs fixup.pl in batch mode
##
## (c) 2005 SAO, Mike Schuster - mschuster@cfa.harvard.edu 
##               and Massimo Marengo - mmarengo@cfa.harvard.edu
##
## ############################################################################

=head1 NAME

perl multi_fixup.pl - runs fixup.pl in batch mode


=head1 SYNOPSIS

 % perl multi_fixup.pl [--help][--ver][--aorlist file][--link]
                       [--pmasks mmmyy][--subarray]


=head1 COMMAND LINE OPTIONS

 --help
   Print usage information and exit.

 --ver
   Print current version and exit.

 --aorlist file
   File with a list of AOR directories (one per field) to process

 --link
   Set this flag if you want to symbolically link to BCD data in AOR dirs,
   Warning: The paths for each AOR dir must be absolute.
   not set by default

 --pmasks mmmyy
   Set of Pmasks, as distributed by the SSC, specified by month and year
   available options: jun06 (default), dec05, jun05, feb05, jan05, oct04, 
   jun04, mar04

 --subarray
   Set this flag if you are processing data taken in sub-array mode
   not set by default


=head1 DESCRIPTION

This script runs the fixup.pl script in batch mode. 

The list of AORs on which to run multi_fixup should be given in the aorlist 
file (aor.lis) as one AOR per field. This script will then read one of the 
README files in the rAOR/ch<CH>/bcd/ sub-directories for each AOR to find the 
Target Name and pass this to fixup as the "proc_dir" parameter. The AOR for 
this field is passed to fixup as the "aor1" parameter. Both absolute and 
relative paths are acceptable for each AOR in aorlist.

One or more spaces in the Target Name will be interpreted as a single "_".


=head1 CHANGES

 2.2 - Removed pixel size to mkmopex_bcd (and its sub-routines)
       Updated w/ new Pmasks from SSC (Apr 27, 2007)
 2.1 - removed options: fif, CROTA2, THRESH_OPTION, MIN_PIX_NUM
       now options for mkmopex_bcd
       added option to symbolically link to BCD data in AOR dirs
       (Apr 11, 2006)
 2.0 - added several options that help to customize the configuration
       files for each specific data set (Feb 16, 2006)
 1.0 - Initial version, replicates earlier version of fixup.pl (Jun 23, 2005)


=head1 AUTHOR

 (c) 2005 Mike Schuster (mschuster@cfa.harvard.edu)
          and M. Marengo (mmarengo@cfa.harvard.edu)
 (c) 2005 SAO - Smithsonian Astrophysical Observatory


=head1 SEE ALSO

 fixup.pl(1);


=head1 BUGS

Report bugs to Mike Schuster, mschuster@cfa.harvard.edu


=cut


## ############################################################################
## Set Modules and version number
## ############################################################################

use warnings;
use strict;
use diagnostics;
use Getopt::Long;

# Set number version
my $VERSION = '2.2';                 # Script version number
my $pname   = 'multi_fixup.pl';      # Script name


## ############################################################################
## Read input options
## ############################################################################

my ($help,$ver,$aorlist,$link);
my ($pmasks,$subarray);

my %optctl = (help            => \$help,
              ver             => \$ver,
              aorlist         => \$aorlist,
              link            => \$link,
              pmasks          => \$pmasks,
              subarray        => \$subarray,
             );

&GetOptions(\%optctl,
            "help",
            "ver",
            "aorlist=s",
            "link",
            "pmasks=s",
            "subarray",
           );


## ############################################################################
## Process input options
## ############################################################################

# Print help and exit
my $usg = "USAGE:  perl $pname [--help][--ver][--aorlist file][--link]\n"
         ."                              [--pmasks mmmyy][--subarray]\n";

if ($help) {
  print STDOUT <<HELP;

  $pname version $VERSION

  runs fixup.pl in batch mode

  $usg

HELP
  exit 0;
}

# Print version and exit
if ($ver) { 
  print "$pname: version $VERSION\n"; 
  exit 0;
}

# Check validity of options
if ($link) {
  print "$pname: WARNING: To link files, the paths for each AOR dir must be absolute\n"; }

# Check the 'aorlist' option
my @dirlist;
if ($aorlist) {
  open(AOR,$aorlist) or die "$pname: cannot open file $aorlist\n";
  foreach (<AOR>) {
	if (m/^ *$/) { next; }
	if (m/^ *\#/) { next; }
	chomp;
	push @dirlist,$_;
  }
  close(AOR);
}

if (not $pmasks) { $pmasks = "jun06"; }
else {
  if (($pmasks ne 'jun06') and ($pmasks ne 'dec05') and ($pmasks ne 'jun05') and ($pmasks ne 'feb05') and ($pmasks ne 'jan05') and ($pmasks ne 'oct04') and ($pmasks ne 'jun04') and ($pmasks ne 'mar04')) {
    print "$pname: ERROR: pmasks must be one of the following:\n";
    print "          jun06, dec05, jun05, feb05, jan05, oct04, jun04, mar04\n";
    exit 0;
  }
}


## ############################################################################
## Read input parameters and run fixup.pl
## ############################################################################

# Input parameters
if (not $aorlist) { print $usg; exit 1; }
my $naors = scalar @dirlist;
if ($naors<1) {
    print "$pname: you should give a list of AORs\n";
    print $usg; exit 1;
}

my $src;

foreach my $aor (@dirlist) {

    # Look for readme file
    my $readme = find_readme(1,$aor);
    if (not $readme) { $readme = find_readme(2,$aor); }
    if (not $readme) { $readme = find_readme(3,$aor); }
    if (not $readme) { $readme = find_readme(4,$aor); }

    if (not $readme) { print "cannot find README file for $aor\n"; next; }

    if (-f $readme) { 

    open(README,$readme);

    foreach (<README>){
        chomp;
        if (m/Target Name +\: +([\w\+\-\ ]+)/) { $src = $1; next; }
    }

    ($src = $src) =~ s/( +)/_/g;

    close(README);

    } else { print "cannot find README file for $aor\n"; next; }

    if ((not $subarray) and (not $link)) {
        system "perl $ENV{IRAC_PROC}/source/fixup.pl -pmasks $pmasks $src $aor"; }

    if (($subarray) and (not $link)) {
        system "perl $ENV{IRAC_PROC}/source/fixup.pl -pmasks $pmasks -subarray $src $aor"; }

    if ((not $subarray) and ($link)) {
        system "perl $ENV{IRAC_PROC}/source/fixup.pl -pmasks $pmasks -link $src $aor"; }

    if (($subarray) and ($link)) {
        system "perl $ENV{IRAC_PROC}/source/fixup.pl -pmasks $pmasks -subarray -link $src $aor"; }

}


## ############################################################################
## So long and thanks for all the fish
## ############################################################################

exit 0;


## ############################################################################
## Find readme file
## ############################################################################

sub find_readme {

    # Input parameter
    my $ch = shift;
    my $aor = shift;

    use vars qw($LS);
    $LS = "ls $aor/ch$ch/bcd/ |";
    open(LS); my @list = <LS>; close(LS);

    my $readme;
    foreach (@list) {
        chomp;
        if (m/README/) { $readme = "$aor/ch$ch/bcd/$_"; }
    }

    # Return
    return $readme;

}

1; # Compiler be happy
